Index: lib/src/runner/environment.dart |
diff --git a/lib/src/runner/environment.dart b/lib/src/runner/environment.dart |
index 33911c4cb9d43cffd3445edbce43711dc25de3a2..f490e0a770ecd61b1a10911eed55b1aec5230e58 100644 |
--- a/lib/src/runner/environment.dart |
+++ b/lib/src/runner/environment.dart |
@@ -4,7 +4,7 @@ |
library test.runner.environment; |
-import '../util/cancelable_future.dart'; |
+import 'package:async/async.dart'; |
/// The abstract class of environments in which test suites are |
/// loaded—specifically, browsers and the Dart VM. |
@@ -19,8 +19,8 @@ abstract class Environment { |
/// Displays information indicating that the test runner is paused. |
/// |
/// The returned future will complete when the user takes action within the |
/// environment that should unpause the runner. If the runner is unpaused |
- /// elsewhere, the future should be canceled. |
- CancelableFuture displayPause(); |
+ /// elsewhere, the operation should be canceled. |
+ CancelableOperation displayPause(); |
} |
@@ -19,8 +19,8 @@ abstract class Environment { |
/// Displays information indicating that the test runner is paused. |
/// |
- /// The returned future will complete when the user takes action within the |
+ /// The returned operation will complete when the user takes action within the |
/// environment that should unpause the runner. If the runner is unpaused |